==> kdepim-addons-17.08.0.tar.xz: kdepim-addons-17.08.0/kmail/editorplugins/changecase/changecaseplugineditorinterface.h <==
/*
   Copyright (C) 2016-2017 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ChangeCasePLUGINEDITORINTERFACE_H
#define ChangeCasePLUGINEDITORINTERFACE_H

#include <messagecomposer/plugineditorinterface.h>

class ChangeCasePluginEditorInterface : public MessageComposer::PluginEditorInterface
{
    Q_OBJECT
public:
    explicit ChangeCasePluginEditorInterface(QObject *parent = nullptr);
    ~ChangeCasePluginEditorInterface();

    void createAction(KActionCollection *ac) override;
    void exec() override;

private:
    void slotUpperCase();
    void slotLowerCase();
    void slotSentenceCase();
    void slotReverseCase();

    void sentenceCase();
    void upperCase();
    void lowerCase();
    void reverseCase();
    enum ChangeCaseType {
        Unknown = -1,
        UpperCase = 0,
        LowerCase,
        SentenseCase,
        ReverseCase
    };
    ChangeCaseType mType;
};

#endif

==> kdepim-addons-19.12.2.tar.xz: kdepim-addons-19.12.2/kmail/editorplugins/changecase/changecaseplugineditorinterface.h <==
/*
   Copyright (C) 2016-2019 Montel Laurent <montel@kde.org>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; see the file COPYING.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
*/

#ifndef ChangeCasePLUGINEDITORINTERFACE_H
#define ChangeCasePLUGINEDITORINTERFACE_H

#include <messagecomposer/plugineditorinterface.h>

class ChangeCasePluginEditorInterface : public MessageComposer::PluginEditorInterface
{
    Q_OBJECT
public:
    explicit ChangeCasePluginEditorInterface(QObject *parent = nullptr);
    ~ChangeCasePluginEditorInterface() override;

    void createAction(KActionCollection *ac) override;
    void exec() override;

private:
    void slotUpperCase();
    void slotLowerCase();
    void slotSentenceCase();
    void slotReverseCase();

    void sentenceCase();
    void upperCase();
    void lowerCase();
    void reverseCase();
    enum ChangeCaseType {
        Unknown = -1,
        UpperCase = 0,
        LowerCase,
        SentenseCase,
        ReverseCase
    };
    ChangeCaseType mType = Unknown;
};

#endif
